@@ -26,6 +26,32 @@ async fn init_api() -> Rest {
     )
 }
 
+#[tokio::test]
+async fn subscribe_unsubscribe() {
+    let mut ws = init_ws().await;
+
+    // Channels: BTC, ETH
+    ws.subscribe(vec![
+        Channel::Trades("BTC-PERP".to_owned()),
+        Channel::Trades("ETH-PERP".to_owned()),
+    ])
+    .await
+    .expect("Subscribe failed");
+
+    // Channels: BTC
+    ws.unsubscribe(vec![Channel::Trades("ETH-PERP".to_owned())])
+        .await
+        .expect("Unsubscribe failed");
+
+    // Channels: BTC, LTC
+    ws.subscribe(vec![Channel::Trades("LTC-PERP".to_owned())])
+        .await
+        .expect("Subscribe failed");
+
+    // Channels: None
+    ws.unsubscribe_all().await.expect("Unsubscribe all failed");
+}
+
 #[tokio::test]
 async fn trades() {
     let mut ws = init_ws().await;
@@ -38,6 +64,8 @@ async fn trades() {
         Some(Data::Trade(..)) => {}
         _ => panic!("Trade data expected."),
     }
+
+    ws.unsubscribe_all().await.expect("Unsubscribe failed");
 }
 
 #[tokio::test]
@@ -55,7 +83,7 @@ async fn order_book_update() {
     match ws.next().await.unwrap() {
         Some(Data::OrderbookData(data)) if data.action == OrderbookAction::Partial => {
             orderbook.update(&data);
-            assert_eq!(orderbook.verify_checksum(data.checksum), true);
+            assert!(orderbook.verify_checksum(data.checksum));
             // println!("{:#?}", orderbook);
         }
         _ => panic!("Order book snapshot data expected."),
@@ -79,20 +107,20 @@ async fn order_book_update() {
 
                 // Update the order book
                 orderbook.update(&data);
-                assert_eq!(orderbook.verify_checksum(data.checksum), true);
+                assert!(orderbook.verify_checksum(data.checksum));
 
                 // Check that removed orders are no longer in the orderbook
                 // Check that inserted orders have been updated correctly
                 for bid in &data.bids {
                     if bid.1 == dec!(0) {
-                        assert_eq!(orderbook.bids.contains_key(&bid.0), false);
+                        assert!(orderbook.bids.contains_key(&bid.0));
                     } else {
                         assert_eq!(orderbook.bids.get(&bid.0), Some(&bid.1));
                     }
                 }
                 for ask in &data.asks {
                     if ask.1 == dec!(0) {
-                        assert_eq!(orderbook.asks.contains_key(&ask.0), false);
+                        assert!(!orderbook.asks.contains_key(&ask.0));
                     } else {
                         assert_eq!(orderbook.asks.get(&ask.0), Some(&ask.1));
                     }
@@ -103,6 +131,8 @@ async fn order_book_update() {
             _ => panic!("Order book update data expected."),
         }
     }
+
+    ws.unsubscribe_all().await.expect("Unsubscribe failed");
 }
 
 #[tokio::test]
@@ -192,7 +222,7 @@ async fn order_book_checksum() {
         match ws.next().await.unwrap() {
             Some(Data::OrderbookData(data)) if data.action == OrderbookAction::Partial => {
                 orderbook.update(&data);
-                assert_eq!(orderbook.verify_checksum(data.checksum), true);
+                assert!(orderbook.verify_checksum(data.checksum));
                 // println!("{:#?}", orderbook);
             }
             _ => panic!("Order book snapshot data expected."),
@@ -202,10 +232,12 @@ async fn order_book_checksum() {
         match ws.next().await.unwrap() {
             Some(Data::OrderbookData(data)) if data.action == OrderbookAction::Update => {
                 orderbook.update(&data);
-                assert_eq!(orderbook.verify_checksum(data.checksum), true);
+                assert!(orderbook.verify_checksum(data.checksum));
             }
             _ => panic!("Order book update data expected."),
         }
+
+        ws.unsubscribe_all().await.expect("Unsubscribe failed");
     }
 }
 
@@ -239,4 +271,6 @@ async fn fills() {
         _ => panic!("Fill data expected."),
     }
     */
+
+    ws.unsubscribe_all().await.expect("Unsubscribe failed");
 }
